@@ -15,14 +15,21 @@
  */
 package net.sf.cglib.core;
 
-import java.io.*;
-import java.util.*;
-import org.objectweb.asm.*;
+import net.sf.cglib.transform.ClassTransformer;
+
+import org.objectweb.asm.ClassVisitor;
+import org.objectweb.asm.FieldVisitor;
+import org.objectweb.asm.MethodVisitor;
+import org.objectweb.asm.Opcodes;
+import org.objectweb.asm.Type;
+
+import java.util.HashMap;
+import java.util.Map;
 
 /**
  * @author Juozas Baliuka, Chris Nokleberg
  */
-public class ClassEmitter extends ClassAdapter {
+public class ClassEmitter extends ClassTransformer {
     private ClassInfo classInfo;
     private Map fieldInfo;
 
@@ -33,12 +40,11 @@ public class ClassEmitter extends ClassAdapter {
     private Signature staticHookSig;
 
     public ClassEmitter(ClassVisitor cv) {
-        super(null);
         setTarget(cv);
     }
 
     public ClassEmitter() {
-        super(null);
+        super(Opcodes.ASM4);
     }
 
     public void setTarget(ClassVisitor cv) {
@@ -142,7 +148,7 @@ public class ClassEmitter extends ClassAdapter {
                                          TypeUtils.toInternalNames(exceptions));
         if (sig.equals(Constants.SIG_STATIC) && !TypeUtils.isInterface(getAccess())) {
             rawStaticInit = v;
-            MethodVisitor wrapped = new MethodAdapter(v) {
+            MethodVisitor wrapped = new MethodVisitor(Opcodes.ASM4, v) {
                 public void visitMaxs(int maxStack, int maxLocals) {
                     // ignore
                 }
