@@ -25,7 +25,7 @@ import org.objectweb.asm.Attribute;
 import org.objectweb.asm.Type;
 
 /**
- * @version $Id: ReflectUtils.java,v 1.28 2005/06/06 17:11:23 herbyderby Exp $
+ * @version $Id: ReflectUtils.java,v 1.30 2009/01/11 19:47:49 herbyderby Exp $
  */
 public class ReflectUtils {
     private ReflectUtils() { }
@@ -381,7 +381,10 @@ public class ReflectUtils {
         
     public static Class defineClass(String className, byte[] b, ClassLoader loader) throws Exception {
         Object[] args = new Object[]{className, b, new Integer(0), new Integer(b.length), PROTECTION_DOMAIN };
-        return (Class)DEFINE_CLASS.invoke(loader, args);
+        Class c = (Class)DEFINE_CLASS.invoke(loader, args);
+        // Force static initializers to run.
+        Class.forName(className, true, loader);
+        return c;
     }
         
     public static int findPackageProtected(Class[] classes) {
@@ -439,4 +442,22 @@ public class ReflectUtils {
             }
         };
     }
+
+    // used by MethodInterceptorGenerated generated code
+    public static Method[] findMethods(String[] namesAndDescriptors, Method[] methods)
+    {
+        Map map = new HashMap();
+        for (int i = 0; i < methods.length; i++) {
+            Method method = methods[i];
+            map.put(method.getName() + Type.getMethodDescriptor(method), method);
+        }
+        Method[] result = new Method[namesAndDescriptors.length / 2];
+        for (int i = 0; i < result.length; i++) {
+            result[i] = (Method)map.get(namesAndDescriptors[i * 2] + namesAndDescriptors[i * 2 + 1]);
+            if (result[i] == null) {
+                // TODO: error?
+            }
+        }
+        return result;
+    }
 }
